@@ -1,4 +1,5 @@
 #' Do a self test to verify \link{babette} that works correctly.
+#' @inheritParams default_params_doc
 #' @author Richèl J.C. Bilderbeek
 #' @export
 #' @examples
@@ -6,10 +7,11 @@
 #' if (is_beast2_installed()) {
 #'   bbt_self_test()
 #' }
-bbt_self_test <- function() {
+bbt_self_test <- function(
+  beast2_options = beastier::create_beast2_options()
+) {
   testit::assert(beastier::is_beast2_installed())
   inference_model <- beautier::create_test_inference_model()
-  beast2_options <- beastier::create_beast2_options()
   babette::bbt_run_from_model(
     fasta_filename = beautier::get_fasta_filename(),
     inference_model = inference_model,
