@@ -27,7 +27,7 @@ check_beast2_pkgs <- function(
       "Must install 'NS' to use 'create_ns_mcmc'. ",
       "Cannot find BEAST2 'NS' package at BEAST2 folder '",
       beast2_folder, "'. ",
-      "Tip: use 'mauricer::install_beast2_pkg(\"NS\")'"
+      "Tip: use 'mauricerinstall::install_beast2_pkg(\"NS\")'"
     )
   }
   if (beautier::is_mcmc_nested_sampling(mcmc) &&
